// set the database and collection we want to use
myDb = db.getSiblingDB('myDb3')
collection = myDb.myCollection

// clear all collection records in advance of CRUD demo
deleteStatus = myDb.myCollection.deleteMany({})

employee1 = {
    "firstName": "John",
    "lastName": "Smith",
    "email": "johnsmith@example.com",
    "department": "IT",
    "password": "abc123",
    "location": { // embedded document
    
        "city": "Columbus",
        "state": "Ohio"
    }
}

employee2 = {
    "firstName": "Jane",
    "lastName": "Bradley",
    "email": "janebradley@example.com",
    "department": "IT",
    "password": "xyz987",
    "location": { // embedded document
    
        "city": "Chicago",
        "state": "Illinois"
    }
}

// insert our employees
collection.insert(employee1)
collection.insert(employee2)

/*
    Queries
*/

// 4.1 Find

print("\nfinding all documents:\n-------------\n")

myDb.myCollection.find({ "department": "IT" }).forEach(
    function(foundDoc){
        printjson(foundDoc)
        // do other things
    }
)
print("\n")

// 4.2 Find One

print("\nfinding one document:\n-------------\n")

foundDoc = myDb.myCollection.findOne({ "department": "IT" })
printjson(foundDoc)
print("\n")

// 4.3 - limit

print("\nfinding all documents, limitting to 1:\n-------------\n")

myDb.myCollection.find({ "department": "IT" }).limit(1).forEach(
    function(foundDoc){
        printjson(foundDoc)
        // do other things
    }
)
print("\n")

// 4.3 - skip

print("\nfinding all documents, skipping the first record:\n-------------\n")

myDb.myCollection.find({ "department": "IT" }).skip(1).forEach(
    function(foundDoc){
        printjson(foundDoc)
        // do other things
    }
)
print("\n")

// 4.3 - sort

print("\nfinding all documents, sorting by last name in ascending order 1:\n-------------\n")

myDb.myCollection.find({ "department": "IT" }).sort({"lastName": 1}).forEach(
    function(foundDoc){
        printjson(foundDoc)
        // do other things
    }
)
print("\n")

// 4.3 - count

print("\nprinting number of documents found:\n-------------\n")
count = myDb.myCollection.find({ "department": "IT" }).count()
printjson(count)
print("\n")

// 4.4 - AND

print("\nfinding all documents with AND:\n-------------\n")

myDb.myCollection.find({ 
    "department": "IT",
    "lastName": "Bradley"
 }).forEach(
    function(foundDoc){
        printjson(foundDoc)
    }
)
print("\n")

// 4.4 - OR

print("\nfinding all documents with OR:\n-------------\n")

myDb.myCollection.find({ 
    "$or": [{
        "email": "johnsmith@example.com"
    }, {
        "lastName": "Bradley"
    }]
 }).forEach(
    function(foundDoc){
        printjson(foundDoc)
    }
)
print("\n")

// 4.4 - in

print("\nfinding all documents with IN:\n-------------\n")

// this is like chaining multiple OR conditions together
myDb.myCollection.find({"lastName":{$in:["Smith", "Adams", "Jones"]}}).forEach(
    function(foundDoc){
        printjson(foundDoc)
    }
)
print("\n")

// 4.5-6 - ﬁnd() method with Projection

print("\nfinding all documents - with projection:\n-------------\n")

myDb.myCollection.find({ "department": "IT" }, {"firstName": 1, "lastName": 1}).forEach(
    function(foundDoc){
        printjson(foundDoc)
        // do other things
    }
)
print("\n")